% demoContextModel.m
%
% Shows the output of the context model on a series of images.  Run it with
% the default settings to see the output of the pedestrian context model.
% To train a new context model, run trainContextModel.m.

function demoContextModel()

addpath('features');

% User input:
% Name of parameter file generated by trainContextModel
% Name of a folder of images on which to demo the model
prompt = {'Enter the name of a parameter file:';'Enter an image folder:'};
userinput=inputdlg(prompt,'Context Model demo',1,{'personwalking';'images'});
parameterFile = (userinput{1});
folder = (userinput{2});

% Demo the model on a folder of images
figure
files = dir(fullfile(folder, '*.jpg'));
for i = 1:length(files)
    
    % Read image
    img = imread(fullfile(folder, files(i).name));
    img = imresize(img, [240 320], 'bilinear', 41);

    % Generate context model map
    focusOfAttention = foa(img, ['contextModels/' parameterFile]);

    % Show the region of the image selected by the model
    subplot(121)
    imshow(img)
    title('Original image')
    subplot(122)
    imshow(uint8(double(img).*repmat(focusOfAttention, [1 1 3])))
    title('Region selected by model')
    drawnow
end
